<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>ActionManager</name>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>&amp;Play</source>
        <translation type="unfinished">&amp;Esegui</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>X</source>
        <translation type="unfinished">X</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>&amp;Pause</source>
        <translation type="unfinished">&amp;Pausa</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>C</source>
        <translation type="unfinished">C</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>&amp;Stop</source>
        <translation type="unfinished">&amp;Arresta</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>V</source>
        <translation type="unfinished">V</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>&amp;Previous</source>
        <translation type="unfinished">&amp;Precedente</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>Z</source>
        <translation type="unfinished">Z</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>&amp;Next</source>
        <translation type="unfinished">&amp;Successivo</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>B</source>
        <translation type="unfinished">B</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>&amp;Play/Pause</source>
        <translation type="unfinished">&amp;Esegui / Pausa</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>Space</source>
        <translation type="unfinished">Spazio</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>J</source>
        <translation type="unfinished">J</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>&amp;Jump to Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>&amp;Repeat Playlist</source>
        <translation type="unfinished">&amp;Ripeti lista brani</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>R</source>
        <translation type="unfinished">R</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>&amp;Repeat Track</source>
        <translation type="unfinished">&amp;Ripeti brano</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>Ctrl+R</source>
        <translation type="unfinished">Ctrl+R</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="47"/>
        <source>&amp;Shuffle</source>
        <translation type="unfinished">&amp;Ordine casuale</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="47"/>
        <source>S</source>
        <translation type="unfinished">S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="48"/>
        <source>&amp;No Playlist Advance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="49"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="50"/>
        <source>&amp;Stop After Selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="51"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="52"/>
        <source>&amp;Clear Queue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="52"/>
        <source>Alt+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Show Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Alt+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="55"/>
        <source>Show Equalizer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="55"/>
        <source>Alt+G</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="56"/>
        <source>Always on Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="57"/>
        <source>Put on All Workspaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="58"/>
        <source>Double Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="58"/>
        <source>Meta+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>&amp;Add File</source>
        <translation type="unfinished">&amp;Aggiungi brani</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>F</source>
        <translation type="unfinished">F</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>&amp;Add Directory</source>
        <translation type="unfinished">&amp;Aggiungi cartelle</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>D</source>
        <translation type="unfinished">D</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="62"/>
        <source>&amp;Add Url</source>
        <translation type="unfinished">&amp;Aggiungi URL</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="62"/>
        <source>U</source>
        <translation type="unfinished">U</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="63"/>
        <source>&amp;Remove Selected</source>
        <translation type="unfinished">&amp;Elimina la selezione</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="64"/>
        <source>Del</source>
        <translation type="unfinished">Canc</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="65"/>
        <source>&amp;Remove All</source>
        <translation type="unfinished">&amp;Elimina tutto</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="66"/>
        <source>&amp;Remove Unselected</source>
        <translation type="unfinished">&amp;Elimina i non selezionati</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="68"/>
        <source>Remove unavailable files</source>
        <translation type="unfinished">Rimuovi files non disponibili</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="70"/>
        <source>Remove duplicates</source>
        <translation type="unfinished">Rimuovi duplicati</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="71"/>
        <source>&amp;Queue Toggle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="71"/>
        <source>Q</source>
        <translation type="unfinished">Q</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="72"/>
        <source>Invert Selection</source>
        <translation type="unfinished">Inverti la selezione</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="73"/>
        <source>&amp;Select None</source>
        <translation type="unfinished">&amp;Non scegliere alcun brano</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="74"/>
        <source>&amp;Select All</source>
        <translation type="unfinished">&amp;Seleziona tutto</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="75"/>
        <source>Ctrl+A</source>
        <translation type="unfinished">Ctrl+A</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="76"/>
        <source>&amp;View Track Details</source>
        <translation type="unfinished">&amp;Dettagli della traccia</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="76"/>
        <source>Alt+I</source>
        <translation type="unfinished">Alt+I</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>&amp;New List</source>
        <translation type="unfinished">&amp;Nuova lista</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>Ctrl+T</source>
        <translation type="unfinished">Ctrl+T</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>&amp;Delete List</source>
        <translation type="unfinished">&amp;Cancella lista</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>Ctrl+W</source>
        <translation type="unfinished">Ctrl+W</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>&amp;Load List</source>
        <translation type="unfinished">&amp;Carica lista</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>O</source>
        <translation type="unfinished">O</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="81"/>
        <source>&amp;Save List</source>
        <translation type="unfinished">&amp;Salva lista</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="81"/>
        <source>Shift+S</source>
        <translation type="unfinished">Shift+S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="82"/>
        <source>&amp;Select Next Playlist</source>
        <translation type="unfinished">&amp;Seleziona la successiva lista esecuzione brani</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="83"/>
        <source>Ctrl+PgDown</source>
        <translation type="unfinished">Ctrl+PgDown</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="84"/>
        <source>&amp;Select Previous Playlist</source>
        <translation type="unfinished">&amp;Seleziona la rpecedente lista esecuzione brani</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="85"/>
        <source>Ctrl+PgUp</source>
        <translation type="unfinished">Ctrl+PgUp</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="86"/>
        <source>&amp;Show Playlists</source>
        <translation type="unfinished">Mostra lista esecuzione brani</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="87"/>
        <source>P</source>
        <translation type="unfinished">P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Configurazione</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>Ctrl+P</source>
        <translation type="unfinished">Ctrl+P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="90"/>
        <source>&amp;About</source>
        <translation type="unfinished">&amp;Informazioni</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>&amp;About Qt</source>
        <translation type="unfinished">&amp;Informazioni su Qt</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="92"/>
        <source>&amp;Exit</source>
        <translation type="unfinished">&amp;Esci</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="92"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished">Ctrl+Q</translation>
    </message>
</context>
<context>
    <name>EqWidget</name>
    <message>
        <location filename="../eqwidget.cpp" line="157"/>
        <location filename="../eqwidget.cpp" line="178"/>
        <source>preset</source>
        <translation>Impostazione</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="264"/>
        <source>&amp;Load/Delete</source>
        <translation>&amp;Carica/Elimina</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="266"/>
        <source>&amp;Save Preset</source>
        <translation>&amp;Salva preimpostazione</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="268"/>
        <source>&amp;Save Auto-load Preset</source>
        <translation>&amp;Salvare preimpostazioni caricate automaticamente</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="273"/>
        <source>&amp;Clear</source>
        <translation>&amp;Cancella</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="302"/>
        <source>Saving Preset</source>
        <translation>Salvataggio preimpostazioni</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="303"/>
        <source>Preset name:</source>
        <translation>Nome delle preimpostazioni: </translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="304"/>
        <source>preset #</source>
        <translation>Preimpostazione #</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="270"/>
        <source>&amp;Import</source>
        <translation>&amp;Importa</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="44"/>
        <source>Equalizer</source>
        <translation type="unfinished">Equalizzatore</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="395"/>
        <source>Import Preset</source>
        <translation>Importa preimpostazione</translation>
    </message>
</context>
<context>
    <name>HotkeyEditor</name>
    <message>
        <location filename="../forms/hotkeyeditor.ui" line="27"/>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/hotkeyeditor.ui" line="32"/>
        <source>Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/hotkeyeditor.ui" line="40"/>
        <source>Change shortcut...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="55"/>
        <source>Playback</source>
        <translation type="unfinished">Riproduzione</translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="61"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="67"/>
        <source>Playlist</source>
        <translation type="unfinished">Lista brani</translation>
    </message>
    <message>
        <location filename="../hotkeyeditor.cpp" line="73"/>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainDisplay</name>
    <message>
        <location filename="../display.cpp" line="57"/>
        <source>Previous</source>
        <translation>Brano precedente</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="61"/>
        <source>Play</source>
        <translation>Esegui</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="64"/>
        <source>Pause</source>
        <translation>Sospendi</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="67"/>
        <source>Stop</source>
        <translation>Ferma</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="70"/>
        <source>Next</source>
        <translation>Brano successivo</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="73"/>
        <source>Add file</source>
        <translation>Aggiungi brani</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="80"/>
        <source>Equalizer</source>
        <translation>Equalizzatore</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="83"/>
        <source>Playlist</source>
        <translation>Lista brani</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="88"/>
        <source>Repeat playlist</source>
        <translation>Ripeti la lista brani</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="91"/>
        <source>Shuffle</source>
        <translation>Ordine casuale</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="101"/>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="107"/>
        <source>Balance</source>
        <translation>Bilanciamento</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="296"/>
        <source>Volume: %1%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../display.cpp" line="300"/>
        <source>Balance: %1% right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../display.cpp" line="302"/>
        <source>Balance: %1% left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../display.cpp" line="304"/>
        <source>Balance: center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../display.cpp" line="315"/>
        <source>Seek to: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainVisual</name>
    <message>
        <location filename="../mainvisual.cpp" line="243"/>
        <source>Visualization Mode</source>
        <translation>Modo visualizzazione</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="246"/>
        <source>Analyzer</source>
        <translation>Analizzatore</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="247"/>
        <source>Scope</source>
        <translation>Oscilloscopio</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="248"/>
        <source>Off</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="255"/>
        <source>Analyzer Mode</source>
        <translation>Modo analizzatore</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="258"/>
        <source>Normal</source>
        <translation>Normale</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="259"/>
        <source>Fire</source>
        <translation>Fuoco</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="260"/>
        <source>Vertical Lines</source>
        <translation>Linee verticali</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="261"/>
        <source>Lines</source>
        <translation>Linee</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="262"/>
        <source>Bars</source>
        <translation>Barre</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="275"/>
        <source>Peaks</source>
        <translation>Picchi</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="279"/>
        <source>Refresh Rate</source>
        <translation>Velocità di aggiornamento</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="282"/>
        <source>50 fps</source>
        <translation>50 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="283"/>
        <source>25 fps</source>
        <translation>25 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="284"/>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="285"/>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="292"/>
        <source>Analyzer Falloff</source>
        <translation>Ricaduta analizzatore</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="295"/>
        <location filename="../mainvisual.cpp" line="309"/>
        <source>Slowest</source>
        <translation>Molto lenta</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="296"/>
        <location filename="../mainvisual.cpp" line="310"/>
        <source>Slow</source>
        <translation>Lenta</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="297"/>
        <location filename="../mainvisual.cpp" line="311"/>
        <source>Medium</source>
        <translation>Media</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="298"/>
        <location filename="../mainvisual.cpp" line="312"/>
        <source>Fast</source>
        <translation>Rapida</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="299"/>
        <location filename="../mainvisual.cpp" line="313"/>
        <source>Fastest</source>
        <translation>Molto veloce</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="306"/>
        <source>Peaks Falloff</source>
        <translation>Ricadua picchi</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="319"/>
        <source>Background</source>
        <translation>Sfondo</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="320"/>
        <source>Transparent</source>
        <translation>Transparente</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Appearance</source>
        <translation type="unfinished">Aspetto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Playlist</source>
        <translation type="unfinished">Lista brani</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>Tools</source>
        <translation>Strumenti</translation>
    </message>
</context>
<context>
    <name>PlayList</name>
    <message>
        <location filename="../playlist.cpp" line="178"/>
        <source>&amp;Copy Selection To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="207"/>
        <source>Sort List</source>
        <translation>Riordina la lista</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="210"/>
        <location filename="../playlist.cpp" line="253"/>
        <source>By Title</source>
        <translation>Per titolo</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="214"/>
        <location filename="../playlist.cpp" line="257"/>
        <source>By Album</source>
        <translation>Per album</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="218"/>
        <location filename="../playlist.cpp" line="261"/>
        <source>By Disc Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="222"/>
        <location filename="../playlist.cpp" line="265"/>
        <source>By Artist</source>
        <translation>PEr interprete</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="226"/>
        <location filename="../playlist.cpp" line="269"/>
        <source>By Filename</source>
        <translation>Per titolo del brano</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="230"/>
        <location filename="../playlist.cpp" line="273"/>
        <source>By Path + Filename</source>
        <translation>per percorso più titolo del brano</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="234"/>
        <location filename="../playlist.cpp" line="277"/>
        <source>By Date</source>
        <translation>Per data</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="242"/>
        <location filename="../playlist.cpp" line="285"/>
        <source>By File Creation Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="250"/>
        <source>Sort Selection</source>
        <translation>Riordina la selezione</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="293"/>
        <source>Randomize List</source>
        <translation>Mescola i brnai della lista</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="295"/>
        <source>Reverse List</source>
        <translation>Inverti la lista</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="565"/>
        <source>&amp;New PlayList</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="238"/>
        <location filename="../playlist.cpp" line="281"/>
        <source>By Track Number</source>
        <translation>Per numero di traccia</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="53"/>
        <source>Playlist</source>
        <translation type="unfinished">Lista brani</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="302"/>
        <source>Actions</source>
        <translation>Azioni</translation>
    </message>
</context>
<context>
    <name>PlayListBrowser</name>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="14"/>
        <source>Playlist Browser</source>
        <translation>Esplora lista esecuzione</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="45"/>
        <source>New</source>
        <translation>Nuova</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="52"/>
        <location filename="../playlistbrowser.cpp" line="40"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="69"/>
        <location filename="../forms/playlistbrowser.ui" line="79"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../playlistbrowser.cpp" line="39"/>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
</context>
<context>
    <name>PlayListSelector</name>
    <message>
        <location filename="../playlistselector.cpp" line="50"/>
        <source>&amp;Load</source>
        <translation>&amp;Carica</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="51"/>
        <source>&amp;Save As...</source>
        <translation>&amp;Salva come</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="53"/>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="54"/>
        <source>&amp;Delete</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="125"/>
        <source>Rename Playlist</source>
        <translation>Rinomina lista brani</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="125"/>
        <source>Playlist name:</source>
        <translation>Nome della lista brani:</translation>
    </message>
</context>
<context>
    <name>PopupSettings</name>
    <message>
        <location filename="../forms/popupsettings.ui" line="14"/>
        <source>Popup Information Settings</source>
        <translation>Popup delle impostazioni</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="75"/>
        <source>Show cover</source>
        <translation>Mostra copertina</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="115"/>
        <source>Transparency:</source>
        <translation>Trasparenza:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="145"/>
        <source>Delay:</source>
        <translation>Ritardo:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="178"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="89"/>
        <source>Cover size:</source>
        <translation>Dimensione copertina:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="29"/>
        <source>Template</source>
        <translation>Modello</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="58"/>
        <source>Reset</source>
        <translation>Azzera</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="65"/>
        <source>Insert</source>
        <translation>Inserisci</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="62"/>
        <source>Artist</source>
        <translation>Interprete</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="63"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="64"/>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="65"/>
        <source>Track number</source>
        <translation>Traccia n°</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="66"/>
        <source>Two-digit track number</source>
        <translation>Traccia n° a due cifre</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="67"/>
        <source>Genre</source>
        <translation>Genere</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="68"/>
        <source>Comment</source>
        <translation>Commento</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="69"/>
        <source>Composer</source>
        <translation>Compositore</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="70"/>
        <source>Duration</source>
        <translation>Durata</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="71"/>
        <source>Disc number</source>
        <translation>Disco n°</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="72"/>
        <source>File name</source>
        <translation>Nome file</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="73"/>
        <source>File path</source>
        <translation>Percorso file</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="74"/>
        <source>Year</source>
        <translation>Anno</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="75"/>
        <source>Condition</source>
        <translation>Condizione</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../forms/preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>Editor delle impostazioni</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="77"/>
        <source>Load</source>
        <translation>Carica</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="84"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="36"/>
        <source>Preset</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="52"/>
        <source>Auto-preset</source>
        <translation>Impostazioni automatiche</translation>
    </message>
</context>
<context>
    <name>ShortcutDialog</name>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="14"/>
        <source>Change Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="52"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SkinnedFactory</name>
    <message>
        <location filename="../skinnedfactory.cpp" line="31"/>
        <source>Skinned User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="44"/>
        <source>About Qmmp Skinned User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="45"/>
        <source>Qmmp Skinned User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="46"/>
        <source>Simple user interface with Winamp-2.x/XMMS skins support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="47"/>
        <source>Written by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedfactory.cpp" line="50"/>
        <source>Artwork:
Andrey Adreev &lt;andreev00@gmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SkinnedSettings</name>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="24"/>
        <source>Skins</source>
        <translation type="unfinished">Temi</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="55"/>
        <source>Add...</source>
        <translation type="unfinished">Aggiungi...</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="68"/>
        <source>Refresh</source>
        <translation type="unfinished">Aggiorna</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="89"/>
        <location filename="../forms/skinnedsettings.ui" line="95"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="101"/>
        <source>Hide on close</source>
        <translation type="unfinished">Nascondi alla chiusura</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="108"/>
        <source>Start hidden</source>
        <translation type="unfinished">Avvia nascosto</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="115"/>
        <source>Use skin cursors</source>
        <translation type="unfinished">Usa cursore skin</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="131"/>
        <source>Fonts</source>
        <translation type="unfinished">Caratteri</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="149"/>
        <source>Player:</source>
        <translation type="unfinished">Player: </translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="171"/>
        <location filename="../forms/skinnedsettings.ui" line="219"/>
        <source>???</source>
        <translation type="unfinished">???</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="178"/>
        <location filename="../forms/skinnedsettings.ui" line="226"/>
        <source>...</source>
        <translation type="unfinished">...</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="197"/>
        <source>Playlist:</source>
        <translation type="unfinished">Lista brani : </translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="233"/>
        <source>Use bitmap font if available</source>
        <translation type="unfinished">Usa carattere bitmap se disponibile</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="243"/>
        <source>Transparency</source>
        <translation type="unfinished">Transparenza</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="249"/>
        <source>Main window</source>
        <translation type="unfinished">Finestra principale</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="272"/>
        <location filename="../forms/skinnedsettings.ui" line="296"/>
        <location filename="../forms/skinnedsettings.ui" line="320"/>
        <source>0</source>
        <translation type="unfinished">0</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="279"/>
        <source>Equalizer</source>
        <translation type="unfinished">Equalizzatore</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="303"/>
        <source>Playlist</source>
        <translation type="unfinished">Lista brani</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="344"/>
        <source>Miscellaneous</source>
        <translation type="unfinished">Varie</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="350"/>
        <source>Song Display</source>
        <translation type="unfinished">Mostra il brano</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="356"/>
        <source>Show protocol</source>
        <translation type="unfinished">Motra protocollo</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="363"/>
        <source>Show song numbers</source>
        <translation type="unfinished">Mostra numero brani</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="387"/>
        <source>Show playlists</source>
        <translation type="unfinished">Mostra lista esecuzione brani</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="394"/>
        <source>Show popup information</source>
        <translation type="unfinished">Mostra informazioni popup</translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="406"/>
        <source>Edit template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="430"/>
        <source>Playlist separator:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="468"/>
        <source>Show &apos;New Playlist&apos; button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="380"/>
        <source>Show anchor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/skinnedsettings.ui" line="373"/>
        <source>Align song numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="101"/>
        <source>Select Skin Files</source>
        <translation type="unfinished">Seleziona aspetto</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="102"/>
        <source>Skin files</source>
        <translation type="unfinished">Aspetto</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="150"/>
        <source>Unarchived skin</source>
        <translation type="unfinished">Tema non archiviato</translation>
    </message>
    <message>
        <location filename="../skinnedsettings.cpp" line="181"/>
        <source>Archived skin</source>
        <translation type="unfinished">Tema archiviato</translation>
    </message>
</context>
<context>
    <name>TextScroller</name>
    <message>
        <location filename="../textscroller.cpp" line="53"/>
        <source>Autoscroll Songname</source>
        <translation>Scorrimento automatico del titolo del brano</translation>
    </message>
    <message>
        <location filename="../textscroller.cpp" line="54"/>
        <source>Transparent Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../textscroller.cpp" line="123"/>
        <source>Buffering: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VisualMenu</name>
    <message>
        <location filename="../visualmenu.cpp" line="26"/>
        <source>Visualization</source>
        <translation>Visualizzazione</translation>
    </message>
</context>
</TS>
